<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="sl">
<context>
    <name>CustomDialog</name>
    <message>
        <location filename="../dialog.cpp" line="16"/>
        <source>Live environment detected. Please select the root partition of the
 system you want to modify (only Linux partitions are displayed)</source>
        <translation>Zaznano je bilo živo okolje. Prosimo, izberite korenski razdelek
sistema, ki ga želite spreminjati (prikazani so le Linux razdelki)</translation>
    </message>
    <message>
        <location filename="../dialog.cpp" line="22"/>
        <source>OK</source>
        <translation>V redu</translation>
    </message>
    <message>
        <location filename="../dialog.cpp" line="23"/>
        <source>Cancel</source>
        <translation>Prekliči</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.ui" line="33"/>
        <source>Options</source>
        <translation>Opcije</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="39"/>
        <source>Use simplified menu structure without submenus</source>
        <translation>Uporabi preprostejšo strukturo menija brez podmenijev</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="42"/>
        <source>Use flat menus (no submenus)</source>
        <translation>Uporabi ploske menije (brez podmenijev)</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="55"/>
        <source>Boot to</source>
        <translation>Zagon v</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="78"/>
        <source>Set to &apos;0&apos; to boot immediately without displaying the menu, or to &apos;-1&apos; to wait indefinitely</source>
        <translation>Nastavi na &apos;0&apos; za takojšen zagon brez prikaza menija ali &apos;-1&apos; za nedoločen čas čakanja</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="81"/>
        <source>Menu timeout</source>
        <translation>Čas prikaza menija</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="104"/>
        <source>Kernel parameters</source>
        <translation>Parametri jedra</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="117"/>
        <source>seconds</source>
        <translation>sekund</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="124"/>
        <source>With this option enabled whatever entry you select from the grub boot menu will be saved as the new default for future boots</source>
        <translation>Če je izbrana ta opcija, bo vsak vnos, ki ga izberete v zagonskem meniju Grub, shranjen kot nova privzeta vrednost za prihodnje zagone</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="127"/>
        <source>Enable saving last boot choice</source>
        <translation>Vklopi shranjevanje izborov zadnjega zagona</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="134"/>
        <source>Manage UEFI Boot Options</source>
        <translation>Upravljanje možnosti UEFI zagona</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="150"/>
        <source>Background</source>
        <translation>Ozadje</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="168"/>
        <source>Image</source>
        <translation>Posnetek</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="181"/>
        <location filename="../mainwindow.ui" line="283"/>
        <source>Enable theme</source>
        <translation>Vklopi temo</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="261"/>
        <source>Splash</source>
        <translation>Pozdrav</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="296"/>
        <source>Preview</source>
        <translation>Predogled</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="319"/>
        <source>Messages</source>
        <translation>Sporočila</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="325"/>
        <source>Very detailed</source>
        <translation>Zelo podrobno</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="332"/>
        <source>Detailed (default setting)</source>
        <translation>Podrobno (privzeto)</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="342"/>
        <source>Limited</source>
        <translation>Omejeno</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="358"/>
        <source>Display log</source>
        <translation>Prikaži dnevnik</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="411"/>
        <source>Display help </source>
        <translation>Prikaži pomoč</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="414"/>
        <source>Help</source>
        <translation>Pomoč</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="421"/>
        <source>Alt+H</source>
        <translation>Alt+H</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="453"/>
        <source>About this application</source>
        <translation>O tem programu</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="456"/>
        <source>About...</source>
        <translation>O programu...</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="463"/>
        <source>Alt+B</source>
        <translation>Alt+B</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="498"/>
        <source>Quit application</source>
        <translation>Zapri aplikacijo</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="501"/>
        <source>Close</source>
        <translation>Zapri</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="508"/>
        <source>Alt+N</source>
        <translation>Alt+N</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="549"/>
        <source>Apply</source>
        <translation>Uveljavi</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="92"/>
        <source>Still running</source>
        <translation>Se še vedno izvaja</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="286"/>
        <source>Set timeout</source>
        <translation>Določi časovno omejitev</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="286"/>
        <source>Timeout in seconds:</source>
        <translation>Časovna omejitev v sekundah</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="290"/>
        <location filename="../mainwindow.cpp" line="618"/>
        <location filename="../mainwindow.cpp" line="1436"/>
        <source>Timeout: %1 seconds</source>
        <translation>Časovna omejitev: %1 sekund</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="303"/>
        <location filename="../mainwindow.cpp" line="620"/>
        <location filename="../mainwindow.cpp" line="1435"/>
        <location filename="../mainwindow.cpp" line="1443"/>
        <source>Boot Next: %1</source>
        <translation>Naslednji zagon: %1</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="317"/>
        <source>Removal confirmation</source>
        <translation>Potrjevanje odstranitve</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="318"/>
        <source>Are you sure you want to delete this boot entry?
%1</source>
        <translation>Ali ste prepričani, da želite ta zagonski vnos?
%1</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="406"/>
        <source>Select EFI file</source>
        <translation>Izberite EFI datoteko</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="406"/>
        <source>EFI files (*.efi *.EFI)</source>
        <translation>EFI datoteke (*.efi *.EFI)</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="418"/>
        <location filename="../mainwindow.cpp" line="433"/>
        <location filename="../mainwindow.cpp" line="519"/>
        <location filename="../mainwindow.cpp" line="527"/>
        <location filename="../mainwindow.cpp" line="561"/>
        <location filename="../mainwindow.cpp" line="603"/>
        <location filename="../mainwindow.cpp" line="703"/>
        <location filename="../mainwindow.cpp" line="792"/>
        <location filename="../mainwindow.cpp" line="1636"/>
        <location filename="../mainwindow.cpp" line="1649"/>
        <location filename="../mainwindow.cpp" line="1655"/>
        <source>Error</source>
        <translation>Napaka</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="418"/>
        <source>Could not find the source mountpoint for %1</source>
        <translation>Priklopne točke vira za %1 ni bilo mogoče najti</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="423"/>
        <source>Set name</source>
        <translation>Določi ime</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="423"/>
        <source>Enter the name for the UEFI menu item:</source>
        <translation>Vnesite ime za UEFI predmet menija:</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="433"/>
        <source>Something went wrong, could not add entry.</source>
        <translation>Nekaj je šlo narobe. Vnosa ni bilo mogoče dodati.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="508"/>
        <source>Installing bootsplash, please wait</source>
        <translation>Namesčanje zagonske predstavitve, prosim počakajte...</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="515"/>
        <source>Updating sources</source>
        <translation>Posodobi vire</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="527"/>
        <source>Could not install the bootsplash.</source>
        <translation>Neuspešno nameščanje zagonske predstavitve</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="603"/>
        <source>Failed to get UEFI boot entries.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="622"/>
        <source>Boot Current: %1</source>
        <translation>Trenutni zagon: %1</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="703"/>
        <source>Could not create a temporary folder</source>
        <translation>Začasne mape ni bilo mogoče ustvariti.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="712"/>
        <location filename="../mainwindow.cpp" line="732"/>
        <source>Cannot continue</source>
        <translation>Ne morem nadaljevati</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="712"/>
        <source>Cannot open LUKS device. Exiting...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="733"/>
        <source>Cannot create chroot environment, cannot change boot options. Exiting...</source>
        <translation>Ne morem ustvaiti chroot okolja, ne morem spremeniti opciji zagona. Končujem...</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="792"/>
        <source>Something went wrong, could not save boot order.</source>
        <translation>Nekaj je šlo narobe. Zagonskega zaporedja ni bilo mogoče dodati.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1078"/>
        <location filename="../mainwindow.cpp" line="1556"/>
        <source>Updating configuration, please wait</source>
        <translation>Posodabljanje konfiguracije, prosimo počakajte</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1149"/>
        <source>Updating initramfs...</source>
        <translation>Posodabljam initramfs</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1163"/>
        <location filename="../mainwindow.cpp" line="1571"/>
        <source>Updating grub...</source>
        <translation>Posodabljam grub...</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1188"/>
        <source>About %1</source>
        <translation>O %1</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1189"/>
        <source>Version: </source>
        <translation>Različica:</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1191"/>
        <source>Program for selecting common start-up choices</source>
        <translation>Program za določitev izbora pri običajnem zagonu</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1193"/>
        <source>Copyright (c) MX Linux</source>
        <translation>Avtorska zaščita (c) MX Linux</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1194"/>
        <source>%1 License</source>
        <translation>%1 licenca</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1215"/>
        <source>%1 Help</source>
        <translation>%1 pomoč</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1225"/>
        <location filename="../mainwindow.cpp" line="1533"/>
        <source>Running in a Virtual Machine</source>
        <translation>Izvajanje v navideznem sistemu</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1226"/>
        <location filename="../mainwindow.cpp" line="1534"/>
        <source>You current system is running in a Virtual Machine,
Plymouth bootsplash will work in a limited way, you also won&apos;t be able to preview the theme</source>
        <translation>Vaš trenutni sistem je zagnan v navidezem sistemu,
Plymouth zagonska predstavitev bo delovala omejeno, poleg tega ni predogleda teme</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1233"/>
        <source>Plymouth packages not installed</source>
        <translation>Plymouth paketi niso nameščeni</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1234"/>
        <source>Plymouth packages are not currently installed.
OK to go ahead and install them?</source>
        <translation>Plymouth paketi trenutno niso nameščeni.
Naj nadaljujem in jih namestim?</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1260"/>
        <source>Images (*.png *.jpg *.jpeg *.tga)</source>
        <translation>Slike (*.png *.jpg *.jpeg *.tga)</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1402"/>
        <source>Log not found</source>
        <translation>Dnevnik ni bil najden</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1402"/>
        <source>Could not find log at </source>
        <translation>Nisem našel dnevnika v </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1409"/>
        <source>Edit UEFI Boot Entries</source>
        <translation>Uredi UEFI zagonske vnose</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1412"/>
        <source>You can use the Up/Down buttons, or drag &amp; drop items to change boot order.
- Items are listed in the boot order.
- Grayed out lines are inactive.</source>
        <translation>Lahko uporabite tipke gor/dol ali vlečete in spustite predmete, da spremenite zagonsko zaporedje.
- Predmeti so navedeni po vrstnem redu zagona.
- Osivele vrstice niso aktivne.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1423"/>
        <location filename="../mainwindow.cpp" line="1471"/>
        <source>Set ac&amp;tive</source>
        <translation>Določi za akt&amp;ivno</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1424"/>
        <source>&amp;Add entry</source>
        <translation>Dod&amp;aj vnos</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1425"/>
        <source>Boot &amp;next</source>
        <translation>&amp;Naslednji zagon</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1636"/>
        <source>Could not retrieve UUID for %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1644"/>
        <source>Enter password to unlock %1 encrypted partition:</source>
        <translation>Vnesite geslo za odklep šifriranega razdelka %1:</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1649"/>
        <source>Password entry cancelled or empty for %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1655"/>
        <source>Could not open %1 LUKS container</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1391"/>
        <location filename="../mainwindow.cpp" line="1426"/>
        <source>&amp;Close</source>
        <translation>&amp;Zapri</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="93"/>
        <source>A process is still running. Do you really want to quit?</source>
        <translation>Vsaj en proces se še vedno izvaja. Želite res končati?</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="154"/>
        <source>Live System Detected</source>
        <translation>Zazna je živi sistem</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="156"/>
        <source>You are currently running a live system. Would you like to modify the boot options for the live system or for an installed system?</source>
        <translation>Trenutno se izvaja živi sistem. Bi radi prilagodili možnosti zagona za živi sistem ali za nameščeni sistem?</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="158"/>
        <source>Live System</source>
        <translation>Živi sistem</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="159"/>
        <source>Installed System</source>
        <translation>Nameščeni sistem</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="519"/>
        <source>Failed to update package sources.</source>
        <translation>Paketnih virov ni bilo mogoče posodobiti.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="523"/>
        <source>Installing packages:</source>
        <translation>Nameščanje paketov:</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="533"/>
        <source>Success</source>
        <translation>Uspešno</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="533"/>
        <source>Bootsplash installed successfully.</source>
        <translation>Bootsplash je bil uspešno nameščen.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="561"/>
        <source>Failed to create temporary file.</source>
        <translation>Začasne datoteke ni bilo mogoče ustvariti.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1171"/>
        <source>You are currently running in live mode with the &apos;toram&apos; option. Please remember to save the persistence file or remaster, otherwise any changes made will be lost.</source>
        <translation>Trenutno se izvaja živi način z možnostjo &apos;toram&apos;. Shranite persistenčno datoteko ali remasterizacijo, sicer se bodo spremembe izgubile.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1173"/>
        <source>Your changes have been successfully applied.</source>
        <translation>Spremembe so bile uspešno izvedene.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1174"/>
        <source>Operation Complete</source>
        <translation>Opravilo je končano</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1259"/>
        <source>Select image to display in bootloader</source>
        <translation>Izberite sliko, ki naj se prikaže v zagonskem nalagalniku</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1383"/>
        <source>Boot Log</source>
        <translation>Zagonski dnevnik</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1427"/>
        <source>Move &amp;down</source>
        <translation>Premakni &amp;dol</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1428"/>
        <source>&amp;Remove entry</source>
        <translation>Odst&amp;rani vnos</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1429"/>
        <source>Re&amp;set next</source>
        <translation>Pona&amp;stavi naslednjega</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1430"/>
        <source>Change &amp;timeout</source>
        <translation>Spremeni &amp;časovno omejitev</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1431"/>
        <source>Move &amp;up</source>
        <translation>Premakni &amp;gor</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1435"/>
        <location filename="../mainwindow.cpp" line="1443"/>
        <source>not set, will boot using list order</source>
        <translation>ni določen. Zagon bo potekal po seznamu</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1468"/>
        <source>Set &amp;inactive</source>
        <translation>Določi za neakt&amp;ivno</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1522"/>
        <source>Needs reboot</source>
        <translation>Potreben je ponovni zagon</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1523"/>
        <source>Plymouth was just installed, you might need to reboot before being able to display previews</source>
        <translation>Plymouth je bil ravnokar nameščen, zato je morda potreben ponovni zagon, da bi lahko prikazal predoglede.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1592"/>
        <source>Click to select theme</source>
        <translation>Kliknite za izbiro teme</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1603"/>
        <source>Select GRUB theme</source>
        <translation>Izberite temo za GRUB</translation>
    </message>
</context>
<context>
    <name>QApplication</name>
    <message>
        <location filename="../main.cpp" line="53"/>
        <source>Program for selecting common start-up choices</source>
        <translation>Program za določitev občajnih izbir ob zagonu</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../about.cpp" line="55"/>
        <source>License</source>
        <translation>Licenca</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="56"/>
        <location filename="../about.cpp" line="65"/>
        <source>Changelog</source>
        <translation>Dnevnik sprememb</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="57"/>
        <source>Cancel</source>
        <translation>Prekliči</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="76"/>
        <source>&amp;Close</source>
        <translation>&amp;Zapri</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="81"/>
        <location filename="../main.cpp" line="90"/>
        <source>Error</source>
        <translation>Napaka</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="82"/>
        <source>You seem to be logged in as root, please log out and log in as normal user to use this program.</source>
        <translation>Prijevljeni ste kot korenski uporabnik. Izpišite se in se ponovno prijavite kot običajen uporabnik, če želite uporabljati ta program.</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="91"/>
        <source>You must run this program with admin access.</source>
        <translation>Ta program je potrebno zagnati s skrbniškim dostopom</translation>
    </message>
</context>
</TS>
